@@ -1,4 +1,4 @@
-#![cfg(any(feature = "2d", feature = "3d"))]
+#![cfg(any(dim2, dim3))]
 
 use rstest::rstest;
 
